<?php
/**
 * Lucene -  My very own search engine
 * (c) 2012 Stefan Rottensteiner, rottensteiner.stefan@gmx.at
 */

/* Der Speicherort für die Lucen files */
$storageDir 	= sys_get_temp_dir().'/lucene/';

echo 'Accessing Lucene in "'.$storageDir.'"' . PHP_EOL;

/* Anlegen wenn nötig */
if ( !file_exists($storageDir)){
  echo 'Creating storage dir' . PHP_EOL;
  mkDir( $storageDir );
} else {
  echo 'Creating storage available' . PHP_EOL;
}

if (!defined('PATH_SEPERATOR')) define('PATH_SEPERATOR',':');

/* ZF in den Include Pfad bringen*/
$currentIncludePath = ini_get('include_path');
ini_set('include_path', $currentIncludePath. PATH_SEPARATOR  .getcwd(). DIRECTORY_SEPARATOR . 'ZendFramework-1.12.0'.DIRECTORY_SEPARATOR.'ZendFramework-1.12.0'.DIRECTORY_SEPARATOR.'library'  );
$currentIncludePath = ini_get('include_path');


/* PHP Autoloader einschalten. Braucht Zend und ist der einzige vernünftige Weg für vieles andere */
function __autoload($class_name) {
    include str_replace('_','/',$class_name) . '.php';
}
/**
 * Hilfsfunktion: Gib mir Zugang zu Lucen
 * @param string $storageDir    Speicherort für die Lucene Files
 * @return Zend_Search_Lucene
 */
function openLuceneIndex($storageDir){
	if ( file_exists($storageDir.DIRECTORY_SEPARATOR.'segments.gen') ) {
#		echo 'Open existing index' . PHP_EOL;
		$Index = Zend_Search_Lucene::open( $storageDir );
	} else {
#		echo 'Create new index' . PHP_EOL;
		$Index = Zend_Search_Lucene::create( $storageDir );
	}
	return $Index;
}
/**
 * Hilfsfunktion: Mache aus HTML-Text reinen Text, umwandeln von Sonderzeichen und ähnliches.
 * @param string $text
 * @return String
 */
function luceneNormalizeHTMLText( $text ){
  $text = strTr($text,array(
	// HTML-Stuff
    "<br>"  	=>  "\n",
    "<br />"	=>  "\n",
    "<br/>" 	=>  "\n",
	'&#39;' 	=>  '\'',
	'&times;'   =>  ' ',
	'&nbsp;'    =>  ' ',
	'&amp;'     =>  '&',
	'&auml;'	=>	'ä',
	'&ouml;'	=>	'ö',
	'&uuml;'	=>	'ü',
	'&Auml;'	=>	'Ä',
	'&Ouml;'	=>	'Ö',
	'&Uuml;'	=>	'Ü',
	'&euro;'	=>	'€',
	'&szlig;'	=>	'ß',
	// Stupid "news paper" quotes
    '„'     	=>  '"',
    '“'     	=>  '"',
	// Line endings
    "\r\n"  	=>  "\n",
    "\r"    	=>  "\n"
  ));
  $text = preg_replace('~\n+~mu',   "\n", $text);
  $text = preg_replace('~[\t ]+~mu'," ",  $text);
  $text = strip_tags($text);
  $text = htmlspecialchars_decode( $text );
  return trim($text);
}

function luceneHaveImportPIDFile(){
	$fileName 	= sys_get_temp_dir().'/lucene.pid';
	if (!file_exists( $fileName )) return FALSE;
	// Wenn älter als 2 Minunten dann löschen.
	if (  (  time() - filemtime( $fileName ) ) > 60*2  ) unlink( $fileName );
	return FALSE;
}
function luceneCreateImportPIDFile(){
	$fileName 	= sys_get_temp_dir().'/lucene.pid';
	return touch( $fileName );
}
function luceneDeleteImportPIDFile(){
	$fileName 	= sys_get_temp_dir().'/lucene.pid';
	if ( file_exists( $fileName ) ) unlink( $fileName );
	return TRUE;
}